==> jc-1.4.0.tar.gz: soot/NormalUnitPrinter.h <==
// public class soot.NormalUnitPrinter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1750eb5ba0ae1ec9 soot_AbstractUnitPrinter
// @dep_class dd5ef11271786ac8 soot_LabeledUnitPrinter
// @dep_class 91cbea65501e4cf2 soot_NormalUnitPrinter

// header file dependencies
// @dep_header soot_LabeledUnitPrinter

#include "soot/LabeledUnitPrinter.h"

#ifndef _JC_soot_NormalUnitPrinter_H_
#define _JC_soot_NormalUnitPrinter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootField$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_IdentityRef$object;

// Typedefs
typedef struct _jc_soot_NormalUnitPrinter$sub_refs	_jc_soot_NormalUnitPrinter$sub_refs;
typedef struct _jc_soot_NormalUnitPrinter$sub_nonrefs	_jc_soot_NormalUnitPrinter$sub_nonrefs;
typedef struct _jc_soot_NormalUnitPrinter$refs	_jc_soot_NormalUnitPrinter$refs;
typedef struct _jc_soot_NormalUnitPrinter$nonrefs	_jc_soot_NormalUnitPrinter$nonrefs;
typedef struct _jc_soot_NormalUnitPrinter$object	_jc_soot_NormalUnitPrinter$object;

typedef const struct _jc_soot_NormalUnitPrinter$vmethods	_jc_soot_NormalUnitPrinter$vmethods;
typedef const struct _jc_soot_NormalUnitPrinter$vtable	_jc_soot_NormalUnitPrinter$vtable;
typedef const struct _jc_soot_NormalUnitPrinter$vtype	_jc_soot_NormalUnitPrinter$vtype;

// Constructors
extern void _jc_soot_NormalUnitPrinter$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_Body$object *);

// Virtual methods
extern void _jc_soot_NormalUnitPrinter$method$fieldRef$5a083ea7f0f1464f(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_SootField$object *);
extern void _jc_soot_NormalUnitPrinter$method$identityRef$0496d0929fd4d759(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_object *);
extern void _jc_soot_NormalUnitPrinter$method$literal$50b4e3e9b9524b5c(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_NormalUnitPrinter$method$method$69518ff24fed1b70(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_SootMethod$object *);
extern void _jc_soot_NormalUnitPrinter$method$type$741203f62135eae6(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_NormalUnitPrinter$method_info$fieldRef$5a083ea7f0f1464f;
extern _jc_method _jc_soot_NormalUnitPrinter$method_info$identityRef$0496d0929fd4d759;
extern _jc_method _jc_soot_NormalUnitPrinter$method_info$literal$50b4e3e9b9524b5c;
extern _jc_method _jc_soot_NormalUnitPrinter$method_info$method$69518ff24fed1b70;
extern _jc_method _jc_soot_NormalUnitPrinter$method_info$type$741203f62135eae6;

// Virtual methods structure
struct _jc_soot_NormalUnitPrinter$vmethods {
	void	(*fieldRef$5a083ea7f0f1464f)(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_SootField$object *);
	void	(*identityRef$0496d0929fd4d759)(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_object *);
	void	(*literal$50b4e3e9b9524b5c)(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_java_lang_String$object *);
	void	(*method$69518ff24fed1b70)(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_SootMethod$object *);
	void	(*type$741203f62135eae6)(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_NormalUnitPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractUnitPrinter$vmethods	soot_AbstractUnitPrinter;
	_jc_soot_LabeledUnitPrinter$vmethods	soot_LabeledUnitPrinter;
	_jc_soot_NormalUnitPrinter$vmethods	soot_NormalUnitPrinter;
};

// Vtype
struct _jc_soot_NormalUnitPrinter$vtype {
	_jc_type			type;
	_jc_soot_NormalUnitPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_NormalUnitPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_NormalUnitPrinter$refs {
    _jc_soot_NormalUnitPrinter$sub_refs	soot_NormalUnitPrinter;
    _jc_soot_LabeledUnitPrinter$sub_refs	soot_LabeledUnitPrinter;
    _jc_soot_AbstractUnitPrinter$sub_refs	soot_AbstractUnitPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_NormalUnitPrinter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_NormalUnitPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractUnitPrinter$sub_nonrefs	soot_AbstractUnitPrinter;
    _jc_soot_LabeledUnitPrinter$sub_nonrefs	soot_LabeledUnitPrinter;
    _jc_soot_NormalUnitPrinter$sub_nonrefs	soot_NormalUnitPrinter;
};

// Object instance structure
struct _jc_soot_NormalUnitPrinter$object {
	_jc_soot_NormalUnitPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_NormalUnitPrinter$vtype	*vtype;
	_jc_soot_NormalUnitPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_NormalUnitPrinter$vtype _jc_soot_NormalUnitPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_NormalUnitPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_NormalUnitPrinter$class_object;

#endif	/* _JC_soot_NormalUnitPrinter_H_ */

==> jc-1.4.6.tar.gz: soot/NormalUnitPrinter.h <==
// public class soot.NormalUnitPrinter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1750eb5ba0ae1ec9 soot_AbstractUnitPrinter
// @dep_class dd5ef11271786ac8 soot_LabeledUnitPrinter
// @dep_class 91cbea65501e4cf2 soot_NormalUnitPrinter

// header file dependencies
// @dep_header soot_LabeledUnitPrinter

#include "soot/LabeledUnitPrinter.h"

#ifndef _JC_soot_NormalUnitPrinter_H_
#define _JC_soot_NormalUnitPrinter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootField$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_IdentityRef$object;

// Typedefs
typedef struct _jc_soot_NormalUnitPrinter$sub_refs	_jc_soot_NormalUnitPrinter$sub_refs;
typedef struct _jc_soot_NormalUnitPrinter$sub_nonrefs	_jc_soot_NormalUnitPrinter$sub_nonrefs;
typedef struct _jc_soot_NormalUnitPrinter$refs	_jc_soot_NormalUnitPrinter$refs;
typedef struct _jc_soot_NormalUnitPrinter$nonrefs	_jc_soot_NormalUnitPrinter$nonrefs;
typedef struct _jc_soot_NormalUnitPrinter$object	_jc_soot_NormalUnitPrinter$object;

typedef const struct _jc_soot_NormalUnitPrinter$vmethods	_jc_soot_NormalUnitPrinter$vmethods;
typedef const struct _jc_soot_NormalUnitPrinter$vtable	_jc_soot_NormalUnitPrinter$vtable;
typedef const struct _jc_soot_NormalUnitPrinter$vtype	_jc_soot_NormalUnitPrinter$vtype;

// Constructors
extern void _jc_soot_NormalUnitPrinter$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_NormalUnitPrinter$method$fieldRef$5a083ea7f0f1464f(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
extern void _jc_soot_NormalUnitPrinter$method$identityRef$0496d0929fd4d759(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_NormalUnitPrinter$method$literal$50b4e3e9b9524b5c(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_NormalUnitPrinter$method$method$69518ff24fed1b70(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern void _jc_soot_NormalUnitPrinter$method$type$741203f62135eae6(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_NormalUnitPrinter$method_info$fieldRef$5a083ea7f0f1464f;
extern _jc_method _jc_soot_NormalUnitPrinter$method_info$identityRef$0496d0929fd4d759;
extern _jc_method _jc_soot_NormalUnitPrinter$method_info$literal$50b4e3e9b9524b5c;
extern _jc_method _jc_soot_NormalUnitPrinter$method_info$method$69518ff24fed1b70;
extern _jc_method _jc_soot_NormalUnitPrinter$method_info$type$741203f62135eae6;

// Virtual methods structure
struct _jc_soot_NormalUnitPrinter$vmethods {
	void	(*fieldRef$5a083ea7f0f1464f)(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
	void	(*identityRef$0496d0929fd4d759)(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*literal$50b4e3e9b9524b5c)(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*method$69518ff24fed1b70)(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
	void	(*type$741203f62135eae6)(_jc_env *, struct _jc_soot_NormalUnitPrinter$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_NormalUnitPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractUnitPrinter$vmethods	soot_AbstractUnitPrinter;
	_jc_soot_LabeledUnitPrinter$vmethods	soot_LabeledUnitPrinter;
	_jc_soot_NormalUnitPrinter$vmethods	soot_NormalUnitPrinter;
};

// Vtype
struct _jc_soot_NormalUnitPrinter$vtype {
	_jc_type			type;
	_jc_soot_NormalUnitPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_NormalUnitPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_NormalUnitPrinter$refs {
    _jc_soot_NormalUnitPrinter$sub_refs	soot_NormalUnitPrinter;
    _jc_soot_LabeledUnitPrinter$sub_refs	soot_LabeledUnitPrinter;
    _jc_soot_AbstractUnitPrinter$sub_refs	soot_AbstractUnitPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_NormalUnitPrinter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_NormalUnitPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractUnitPrinter$sub_nonrefs	soot_AbstractUnitPrinter;
    _jc_soot_LabeledUnitPrinter$sub_nonrefs	soot_LabeledUnitPrinter;
    _jc_soot_NormalUnitPrinter$sub_nonrefs	soot_NormalUnitPrinter;
};

// Object instance structure
struct _jc_soot_NormalUnitPrinter$object {
	_jc_soot_NormalUnitPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_NormalUnitPrinter$vtype	*vtype;
	_jc_soot_NormalUnitPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_NormalUnitPrinter$vtype _jc_soot_NormalUnitPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_NormalUnitPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_NormalUnitPrinter$class_object;

#endif	/* _JC_soot_NormalUnitPrinter_H_ */
